@@ -7,7 +7,8 @@ localClusteringCoeff <- function(g, deg=NULL){
   if(is.null(deg)){ 
     deg <- graph::degree(g)
   }
-  lcc <- (2)/(deg*(deg-1))
+  #lcc <- (2*length(edges(g)))/(deg*(deg-1))
+  lcc <- igraph::transitivity(igraph.from.graphNEL(g), type='local') 
   names(lcc) <- nodes(g)
   return(lcc)
 }
